;; Generated package description from map.el  -*- no-byte-compile: t -*-
(define-package "map" "3.3.1" "Map manipulation functions" '((emacs "26")) :commit "9da2efb670574b473ab864ae0456b4f1b38e680b" :url "https://elpa.gnu.org/packages/map.html" :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("extensions" "lisp"))
